c    This is to manage a new non-default  volume/shape which is not
c    included in Epics.
c   This is the interface to draw new volumes.
      subroutine epDrawNew(comp, p, n)
      implicit none
#include "Zep3Vec.h"
#include "Zcnfig.h"
#include "ZepPos.h"
      record /Component/comp  ! input. given component to be drawn
      integer n   !  ouput.  number of segments given in p 
      record /epPos/ p(*)  ! output.   position given in local coord.

c      
      if(comp.struc(1:8) .eq. 'angle') then
         call epDraw_angle(comp, p, n)
c---  elseif(comp.struc(1:8) .eq. '%2') then
c---     call epDraw_%2(comp, p, n)
      else
         call cerrorMsg(comp.struc(1:8), 1)
         call cerrorMsg(' is not supported: epDrawNew; Maybe', 1)
         call cerrorMsg(
     *    "You havent done mkNewVolume 'your-config-file'",
     *     0)
      endif

      end
